API Reference
=============

.. toctree::
   :hidden:

   dist
   metrics
   tracks

.. currentmodule:: evaldet

Distance
--------

.. autosummary::

   dist.iou_dist

Metrics
-------

.. autosummary::

   MOTMetrics


Tracks
------

.. autosummary::

   Tracks
